@@ -16,9 +16,10 @@
 #' @field sessionid Stores id of your current session on the server.
 #' @field url Stores url of the last visualization created by this object.
 #' @field autoopen Checks if the server is automatically opening the visualizations.
+#' @field notebook Checks if the server is in the jupyter notebook mode.
 #' #' @section Methods:
 #' \describe{
-#'   \item{Documentation}{For full documentation of each method go to https://github.com/Ermlab/lightining-rstat/}
+#'   \item{Documentation}{For full documentation of each method go to https://github.com/lightning-viz/lightining-r/}
 #'   \item{\code{new(serveraddress)}}{This method is used to create object of this class with \code{serveraddress} as address of the server object is connecting to.}
 #'
 #'   \item{\code{sethost(serveraddress)}}{This method changes server that you are contacting with to \code{serveraddress}.}
@@ -45,15 +46,18 @@ Lightning <- R6Class("Lightning",
    public = list(
       serveraddress = NA,
       sessionid = NA,
+      notebook = NA,
       url = NA,
       autoopen = FALSE,
-      initialize = function(serveraddress) {
+      initialize = function(serveraddress, notebook = F) {
          if(!missing(serveraddress)){
             self$serveraddress <- serveraddress
          }
+
+         self$notebook = notebook
       },
       line = function(series, index = NA, color = NA, label = NA, size = NA, xaxis = NA, yaxis = NA, logScaleX = "false", logScaleY = "false") {
-         listbuilder <- list(type = "line", opts = list(logScaleX = logScaleX, logScaleY = logScaleY))
+         listbuilder <- list(type = "line", options = list(logScaleX = logScaleX, logScaleY = logScaleY))
          features <- list(series = series)
 
          if (!is.na(index)) {
@@ -76,6 +80,11 @@ Lightning <- R6Class("Lightning",
          }
 
          listbuilder$data <- features
+         if(self$notebook) {
+            listbuilder$options$width = 600
+         }
+
+
 
          jsonbody <- toJSON(listbuilder, .na = "")
          oldbody = "placeholder"
@@ -87,6 +96,7 @@ Lightning <- R6Class("Lightning",
          jsonbody <- gsub(",  ]", " ]", jsonbody)
          jsonbody <- gsub('[ ,', '[', jsonbody, fixed = TRUE)
          httpheader<- c(Accept = "text/plain", "Content-Type" = "application/json")
+
          response = postForm(paste(self$serveraddress, "sessions/", self$sessionid, "/visualizations/", sep=""),
                              .opts = list(httpheader = httpheader, postfields=jsonbody))
          response = fromJSON(response)
@@ -95,10 +105,13 @@ Lightning <- R6Class("Lightning",
          if (self$autoopen) {
             browseURL(url)
          }
+         if(self$notebook) {
+            return(display_html(getURLContent(paste(url, "embed/", sep=""))))
+         }
          return(list(url = url, id = response$id))
       },
       scatter = function(x, y, color = NA, label = NA, size = NA, alpha = NA, xaxis = NA, yaxis = NA){
-         listbuilder <- list(type = "scatter")
+         listbuilder <- list(type = "scatter", options = list())
          points <- matrix(ncol = 2, nrow = length(x))
          points[,1] <- x
          points[,2] <- y
@@ -124,7 +137,10 @@ Lightning <- R6Class("Lightning",
          }
 
          listbuilder$data <- features
-         listbuilder$opts <- c(NaN)
+         if(self$notebook) {
+            listbuilder$options$width = 600
+         }
+
          jsonbody <- toJSON(listbuilder, .na = "{}")
          httpheader<- c(Accept = "text/plain", "Content-Type" = "application/json")
          response = postForm(paste(self$serveraddress, "sessions/", self$sessionid, "/visualizations/", sep=""),
@@ -135,10 +151,13 @@ Lightning <- R6Class("Lightning",
             browseURL(url)
          }
          self$url <- url
+         if(self$notebook) {
+            return(display_html(getURLContent(paste(url, "embed/", sep=""))))
+         }
          return(list(url = url, id = response$id))
       },
       linestacked = function(series, color = NA, label = NA, size = NA){
-         listbuilder <- list(type = "line-stacked")
+         listbuilder <- list(type = "line-stacked", options = list())
          features <- list(series = series)
 
          if (!is.na(color)) {
@@ -152,7 +171,10 @@ Lightning <- R6Class("Lightning",
          }
 
          listbuilder$data <- features
-         listbuilder$opts <- c("options")
+         if(self$notebook) {
+            listbuilder$options$width = 600
+         }
+
          jsonbody <- toJSON(listbuilder, .na = "")
 
          oldbody = "placeholder"
@@ -174,12 +196,15 @@ Lightning <- R6Class("Lightning",
          if (self$autoopen) {
             browseURL(url)
          }
+         if(self$notebook) {
+            return(display_html(getURLContent(paste(url, "embed/", sep=""))))
+         }
          return(list(url = url, id = response$id))
       },
       force = function(matrix, color = NA, label = NA, size = NA){
          ##matrix- connectivity matrix n by n, where value is the weight of the edge
 
-         listbuilder <- list(type = "force", opts = NA)
+         listbuilder <- list(type = "force", options = list())
          nodes <- vector(mode = "numeric", length = nrow(matrix))
          for (i in 0:(length(nodes)-1)) {
             nodes[i] <- i
@@ -209,6 +234,10 @@ Lightning <- R6Class("Lightning",
          }
 
          listbuilder$data <- features
+         if(self$notebook) {
+            listbuilder$options$width = 600
+         }
+
 
          jsonbody <- toJSON(listbuilder, .na = "{}")
          httpheader<- c(Accept = "text/plain", "Content-Type" = "application/json")
@@ -220,10 +249,13 @@ Lightning <- R6Class("Lightning",
          if (self$autoopen) {
             browseURL(url)
          }
+         if(self$notebook) {
+            return(display_html(getURLContent(paste(url, "embed/", sep=""))))
+         }
          return(list(url = url, id = response$id))
       },
       graph = function(x, y, matrix, color = NA, label = NA, size = NA) {
-         listbuilder <- list(type = "graph", opts = NA)
+         listbuilder <- list(type = "graph", options = list())
          points <- matrix(ncol = 2, nrow = length(x))
          points[,1] <- x
          points[,2] <- y
@@ -251,6 +283,9 @@ Lightning <- R6Class("Lightning",
          }
 
          listbuilder$data <- features
+         if(self$notebook) {
+            listbuilder$options$width = 600
+         }
          jsonbody <- toJSON(listbuilder, .na = "{}")
          httpheader<- c(Accept = "text/plain", "Content-Type" = "application/json")
          response = postForm(paste(self$serveraddress, "sessions/", self$sessionid, "/visualizations/", sep=""),
@@ -261,12 +296,20 @@ Lightning <- R6Class("Lightning",
          if (self$autoopen) {
             browseURL(url)
          }
+         if(self$notebook) {
+            return(display_html(getURLContent(paste(url, "embed/", sep=""))))
+         }
          return(list(url = url, id = response$id))
       },
       map = function(regions, weights, colormap) {
-         listbuilder <- list(type = "map", opts = NA)
+         listbuilder <- list(type = "map", options = list())
          features = list(regions = regions, values = weights, colormap = colormap)
          listbuilder$data <- features
+
+         if(self$notebook) {
+            listbuilder$options$width = 600
+         }
+
          jsonbody <- toJSON(listbuilder, .na = "{}")
          httpheader<- c(Accept = "text/plain", "Content-Type" = "application/json")
          response = postForm(paste(self$serveraddress, "sessions/", self$sessionid, "/visualizations/", sep=""),
@@ -277,10 +320,13 @@ Lightning <- R6Class("Lightning",
          if (self$autoopen) {
             browseURL(url)
          }
+         if(self$notebook) {
+            return(display_html(getURLContent(paste(url, "embed/", sep=""))))
+         }
          return(list(url = url, id = response$id))
       },
       graphbundled = function(x, y, matrix, color = NA, label = NA, size = NA){
-         listbuilder <- list(type = "graph-bundled", opts = NA)
+         listbuilder <- list(type = "graph-bundled", options = list())
          points <- matrix(ncol = 2, nrow = length(x))
          points[,1] <- x
          points[,2] <- y
@@ -308,6 +354,11 @@ Lightning <- R6Class("Lightning",
          }
 
          listbuilder$data <- features
+
+         if(self$notebook) {
+            listbuilder$options$width = 600
+         }
+
          jsonbody <- toJSON(listbuilder, .na = "{}")
          httpheader<- c(Accept = "text/plain", "Content-Type" = "application/json")
          response = postForm(paste(self$serveraddress, "sessions/", self$sessionid, "/visualizations/", sep=""),
@@ -318,12 +369,20 @@ Lightning <- R6Class("Lightning",
          if (self$autoopen) {
             browseURL(url)
          }
+         if(self$notebook) {
+            return(display_html(getURLContent(paste(url, "embed/", sep=""))))
+         }
          return(list(url = url, id = response$id))
       },
       matrix = function(matrix, colormap){
-         listbuilder <- list(type = "matrix", opts = NA)
+         listbuilder <- list(type = "matrix", options = list())
          features = list(matrix = matrix, colormap = colormap)
          listbuilder$data <- features
+
+         if(self$notebook) {
+            listbuilder$options$width = 600
+         }
+
          jsonbody <- toJSON(listbuilder, .na = "{}")
          httpheader<- c(Accept = "text/plain", "Content-Type" = "application/json")
          response = postForm(paste(self$serveraddress, "sessions/", self$sessionid, "/visualizations/", sep=""),
@@ -337,7 +396,7 @@ Lightning <- R6Class("Lightning",
          return(list(url = url, id = response$id))
       },
       adjacency = function (matrix, label = NA) {
-         listbuilder <- list(type = "adjacency", opts = NA)
+         listbuilder <- list(type = "adjacency", options = list())
          nodes <- c(0:(nrow(matrix) - 1))
          links <- matrix(ncol = 3, byrow = TRUE)
          for (i in 1:ncol(matrix)) {
@@ -355,6 +414,10 @@ Lightning <- R6Class("Lightning",
          }
 
          listbuilder$data <- features
+         if(self$notebook) {
+            listbuilder$options$width = 600
+         }
+
          jsonbody <- toJSON(listbuilder, .na = "{}")
          httpheader<- c(Accept = "text/plain", "Content-Type" = "application/json")
          response = postForm(paste(self$serveraddress, "sessions/", self$sessionid, "/visualizations/", sep=""),
@@ -365,10 +428,13 @@ Lightning <- R6Class("Lightning",
          if (self$autoopen) {
             browseURL(url)
          }
+         if(self$notebook) {
+            return(display_html(getURLContent(paste(url, "embed/", sep=""))))
+         }
          return(list(url = url, id = response$id))
       },
       scatterline = function(x, y, t, color = NA, label = NA, size = NA){
-         listbuilder <- list(type = "scatter-line")
+         listbuilder <- list(type = "scatter-line", options=list())
          points <- matrix(ncol = 2, nrow = length(x))
          points[,1] <- x
          points[,2] <- y
@@ -385,7 +451,10 @@ Lightning <- R6Class("Lightning",
          }
 
          listbuilder$data <- features
-         listbuilder$opts <- c("options")
+         if(self$notebook) {
+            listbuilder$options$width = 600
+         }
+
          jsonbody <- toJSON(listbuilder, .na = "")
          oldbody = "placeholder"
 
@@ -406,10 +475,13 @@ Lightning <- R6Class("Lightning",
          if (self$autoopen) {
             browseURL(url)
          }
+         if(self$notebook) {
+            return(display_html(getURLContent(paste(url, "embed/", sep=""))))
+         }
          return(list(url = url, id = response$id))
       },
       scatter3 = function(x, y, z, color = NA, label = NA, size = NA, alpha = NA) {
-         listbuilder <- list(type = "scatter-3")
+         listbuilder <- list(type = "scatter-3", options=list())
          points <- matrix(ncol = 3, nrow = length(x))
          points[,1] <- x
          points[,2] <- y
@@ -430,7 +502,11 @@ Lightning <- R6Class("Lightning",
          }
 
          listbuilder$data <- features
-         listbuilder$opts <- c(NaN)
+
+         if(self$notebook) {
+            listbuilder$options$width = 600
+         }
+
          jsonbody <- toJSON(listbuilder, .na = "{}")
          httpheader<- c(Accept = "text/plain", "Content-Type" = "application/json")
          response = postForm(paste(self$serveraddress, "sessions/", self$sessionid, "/visualizations/", sep=""),
@@ -441,10 +517,18 @@ Lightning <- R6Class("Lightning",
          if (self$autoopen) {
             browseURL(url)
          }
+         if(self$notebook) {
+            return(display_html(getURLContent(paste(url, "embed/", sep=""))))
+         }
          return(list(url = url, id = response$id))
       },
       image = function(imgpath) {
-         rawresponse <- POST(url = paste(self$serveraddress, "sessions/", self$sessionid, "/visualizations/", sep=""), encode = 'multipart', body = list(file = upload_file(imgpath), type = "image"))
+         body = list(file = upload_file(imgpath), type = "image", options = list())
+         if(self$notebook) {
+            body$options$width = 600
+         }
+
+         rawresponse <- POST(url = paste(self$serveraddress, "sessions/", self$sessionid, "/visualizations/", sep=""), encode = 'multipart', body = body)
          jsonstring <- rawToChar(rawresponse$content)
          response <- fromJSON(jsonstring)
          url <- paste(self$serveraddress, "visualizations/", response$id, "/", sep="")
@@ -452,12 +536,21 @@ Lightning <- R6Class("Lightning",
          if (self$autoopen) {
             browseURL(url)
          }
+         if(self$notebook) {
+            return(display_html(getURLContent(paste(url, "embed/", sep=""))))
+         }
          return(list(url = url, id = response$id))
       },
       gallery = function(imgpathvector) {
          firstpath <- imgpathvector[1]
          otherpaths <- imgpathvector[-1]
-         rawresponse <- POST(url = paste(self$serveraddress, "sessions/", self$sessionid, "/visualizations/", sep=""), encode = 'multipart', body = list(file = upload_file(firstpath), type = "gallery"))
+
+         body = list(file = upload_file(firstpath), type = "gallery", options = list())
+         if(self$notebook) {
+            body$options$width = 600
+         }
+
+         rawresponse <- POST(url = paste(self$serveraddress, "sessions/", self$sessionid, "/visualizations/", sep=""), encode = 'multipart', body = body)
          jsonstring <- rawToChar(rawresponse$content)
          response <- fromJSON(jsonstring)
          url <- paste(self$serveraddress, "visualizations/", response$id, "/", sep="")
@@ -468,6 +561,9 @@ Lightning <- R6Class("Lightning",
          if (self$autoopen) {
             browseURL(url)
          }
+         if(self$notebook) {
+            return(display_html(getURLContent(paste(url, "embed/", sep=""))))
+         }
          return(list(url = url, id = response$id))
       },
       createsession = function(sessionname = ""){
@@ -476,7 +572,7 @@ Lightning <- R6Class("Lightning",
          response = postForm(paste(self$serveraddress, "sessions/", sep=""),
                              .opts = list(httpheader = httpheader, postfields=jsonbody))
          response = fromJSON(response)
-         self$sessionid <- response$id
+         self$sessionid <- response["id"]
          return(response)
       },
       usesession = function(sessionid){
